==> feflow-devkit-xbc-webpack4-react-1.0.8.tgz: package/lib/webpack/webpack.base.config.js <==
"use strict";

var autoprefixer = require('autoprefixer');

var glob = require('glob');

var path = require('path');

var CleanWebpackPlugin = require('clean-webpack-plugin');

var HtmlWebpackPlugin = require('html-webpack-plugin'); // const MiniCssExtractPlugin = require('mini-css-extract-plugin');


var CopyWebpackPlugin = require("copy-webpack-plugin");

var VueLoaderPlugin = require("vue-loader/lib/plugin");

var projectRoot = process.cwd(); // 设置多页配置
// const setMPA = () => {
//   const entry = {};
//   const htmlWebpackPlugins = [];
//   const entryFiles = glob.sync(path.join(projectRoot, './src/*/index.js'));
//   Object.keys(entryFiles)
//     .map((index) => {
//       const entryFile = entryFiles[index];
//       const match = entryFile.match(/src\/(.*)\/index\.js/);
//       const pageName = match && match[1];
//       entry[pageName] = entryFile;
//       return htmlWebpackPlugins.push(
//         new HtmlWebpackPlugin({
//           inlineSource: '.css$',
//           template: path.join(projectRoot, `./src/${pageName}/index.html`),
//           filename: `${pageName}.html`,
//           chunks: ['vendors', pageName],
//           inject: true,
//           minify: {
//             html5: true,
//             collapseWhitespace: true,
//             preserveLineBreaks: false,
//             minifyCSS: true,
//             minifyJS: true,
//             removeComments: false,
//           },
//         })
//       );
//     });
//   return {
//     entry,
//     htmlWebpackPlugins,
//   };
// };
// const { entry, htmlWebpackPlugins } = setMPA();

var entry = path.join(projectRoot, './src/index.js');
module.exports = {
  // context: path.join(projectRoot, "./"),
  entry: entry,
  output: {
    path: path.join(projectRoot, "dist"),
    filename: "static/js/[name].[hash].bundle.js",
    chunkFilename: "static/js/[name].[chunkhash].bundle.js",
    pathinfo: false,
    publicPath: "/"
  },
  // output: {
  //   path: path.resolve(__dirname, "../dist"),
  //   filename: "static/js/[name].[hash].bundle.js",
  //   chunkFilename: "static/js/[name].[chunkhash].bundle.js",
  //   pathinfo: false,
  //   publicPath: "/"
  // },
  // externals: {
  //   react: "React",
  //   "react-dom": "ReactDOM"
  // },
  resolveLoader: {
    // modules: ["node_modules"]
    modules: [path.resolve(__dirname, "../../node_modules"), path.join(projectRoot, "node_modules")]
  },
  resolve: {
    extensions: [".ts", ".js", "jsx", ".tsx", ".json", ".vue"],
    alias: {
      vue$: "vue/dist/vue.esm.js",
      app: path.join(projectRoot, "./src/app.js"),
      "@": path.join(projectRoot, "./src")
    },
    mainFiles: ["index"],
    // modules: ["node_modules"],
    modules: [path.resolve(__dirname, "../../node_modules"), path.join(projectRoot, "node_modules")]
  },
  module: {
    rules: [{
      test: /\.vue$/,
      exclude: [/node-modules/],
      use: [{
        loader: "thread-loader"
      }, {
        loader: "cache-loader"
      }, {
        loader: "vue-loader"
      }]
    }, {
      test: /\.js$/,
      exclude: [path.join(projectRoot, "node_modules"), path.resolve(__dirname, "../../node_modules")],
      use: [{
        loader: "thread-loader"
      }, {
        loader: "babel-loader",
        options: {
          cacheDirectory: true,
          compact: false
        }
      }]
    }, {
      test: /\.(j|t)sx?$/,
      use: [{
        loader: "thread-loader"
      }, {
        loader: "babel-loader",
        options: {
          cacheDirectory: true,
          compact: false
        }
      }],
      exclude: [path.join(projectRoot, "node_modules"), path.resolve(__dirname, "../../node_modules")] // exclude: path.resolve(__dirname, "../../node_modules")

    }, {
      test: /\.(png|svg|jpg|gif)$/,
      use: [{
        loader: "url-loader",
        options: {
          limit: 10000,
          name: "static/img/[name].[hash:7].[ext]"
        }
      }]
    }, {
      test: /\.(woff|woff2|eot|ttf|otf)$/,
      use: [{
        loader: "url-loader",
        options: {
          limit: 10000,
          name: "static/fonts/[name].[hash:7].[ext]"
        }
      }]
    }, {
      test: /\.(mp4|webm|ogg|mp3|wav|flac|aac)(\?.*)?$/,
      use: [{
        loader: "url-loader",
        options: {
          limit: 10000,
          name: "static/media/[name].[hash:7].[ext]"
        }
      }]
    }]
  },
  plugins: [// new MiniCssExtractPlugin({
  //   filename: "[name]_[contenthash:8].css"
  // }),
  new VueLoaderPlugin(), new CleanWebpackPlugin(), new HtmlWebpackPlugin({
    filename: "index.html",
    template: path.join(projectRoot, "index.html") // inject: true,

  }), new CopyWebpackPlugin([{
    from: path.join(projectRoot, "./static"),
    to: "static",
    ignore: [".*"]
  }])] //   function errorPlugin() {
  //     this.hooks.done.tap('done', (stats) => {
  //       if (stats.compilation.errors && stats.compilation.errors.length && process.argv.indexOf('--watch') === -1) {
  //         process.exit(1);
  //       }
  //     });
  //   },
  // ].concat(htmlWebpackPlugins)

};

==> feflow-devkit-xbc-webpack4-react-1.0.9.tgz: package/lib/webpack/webpack.base.config.js <==
"use strict";

var autoprefixer = require('autoprefixer');

var glob = require('glob');

var path = require('path');

var CleanWebpackPlugin = require('clean-webpack-plugin');

var HtmlWebpackPlugin = require('html-webpack-plugin'); // const MiniCssExtractPlugin = require('mini-css-extract-plugin');


var CopyWebpackPlugin = require("copy-webpack-plugin"); // const VueLoaderPlugin = require("vue-loader/lib/plugin");


var threadLoader = require("thread-loader");

var projectRoot = process.cwd(); // 设置多页配置
// const setMPA = () => {
//   const entry = {};
//   const htmlWebpackPlugins = [];
//   const entryFiles = glob.sync(path.join(projectRoot, './src/*/index.js'));
//   Object.keys(entryFiles)
//     .map((index) => {
//       const entryFile = entryFiles[index];
//       const match = entryFile.match(/src\/(.*)\/index\.js/);
//       const pageName = match && match[1];
//       entry[pageName] = entryFile;
//       return htmlWebpackPlugins.push(
//         new HtmlWebpackPlugin({
//           inlineSource: '.css$',
//           template: path.join(projectRoot, `./src/${pageName}/index.html`),
//           filename: `${pageName}.html`,
//           chunks: ['vendors', pageName],
//           inject: true,
//           minify: {
//             html5: true,
//             collapseWhitespace: true,
//             preserveLineBreaks: false,
//             minifyCSS: true,
//             minifyJS: true,
//             removeComments: false,
//           },
//         })
//       );
//     });
//   return {
//     entry,
//     htmlWebpackPlugins,
//   };
// };
// const { entry, htmlWebpackPlugins } = setMPA();

var entry = path.join(projectRoot, './src/index.js');
module.exports = {
  // context: path.join(projectRoot, "./"),
  entry: entry,
  output: {
    path: path.join(projectRoot, "dist"),
    filename: "static/js/[name].[hash].bundle.js",
    chunkFilename: "static/js/[name].[chunkhash].bundle.js",
    pathinfo: false,
    publicPath: "/"
  },
  // output: {
  //   path: path.resolve(__dirname, "../dist"),
  //   filename: "static/js/[name].[hash].bundle.js",
  //   chunkFilename: "static/js/[name].[chunkhash].bundle.js",
  //   pathinfo: false,
  //   publicPath: "/"
  // },
  // externals: {
  //   react: "React",
  //   "react-dom": "ReactDOM"
  // },
  resolveLoader: {
    // modules: ["node_modules"]
    modules: [path.resolve(__dirname, "../../node_modules"), path.join(projectRoot, "node_modules")]
  },
  resolve: {
    extensions: [".ts", ".js", "jsx", ".tsx", ".json", ".vue"],
    alias: {
      vue$: "vue/dist/vue.esm.js",
      app: path.join(projectRoot, "./src/app.js"),
      "@": path.join(projectRoot, "./src")
    },
    mainFiles: ["index"],
    // modules: ["node_modules"],
    modules: [path.resolve(__dirname, "../../node_modules"), path.join(projectRoot, "node_modules")]
  },
  module: {
    rules: [// {
    //   test: /\.vue$/,
    //   exclude: [/node-modules/],
    //   use: [
    //     {
    //       loader: "thread-loader"
    //     },
    //     {
    //       loader: "cache-loader"
    //     },
    //     {
    //       loader: "vue-loader"
    //     }
    //   ]
    // },
    {
      test: /\.js$/,
      exclude: [path.join(projectRoot, "node_modules"), path.resolve(__dirname, "../../node_modules")],
      use: [{
        loader: "thread-loader"
      }, {
        loader: "babel-loader",
        options: {
          cacheDirectory: true,
          compact: false
        }
      }]
    }, {
      test: /\.(j|t)sx?$/,
      use: [{
        loader: "thread-loader"
      }, {
        loader: "babel-loader",
        options: {
          cacheDirectory: true,
          compact: false
        }
      }],
      exclude: [path.join(projectRoot, "node_modules"), path.resolve(__dirname, "../../node_modules")] // exclude: path.resolve(__dirname, "../../node_modules")

    }, {
      test: /\.(png|svg|jpg|gif)$/,
      use: [{
        loader: "url-loader",
        options: {
          limit: 10000,
          name: "static/img/[name].[hash:7].[ext]"
        }
      }]
    }, {
      test: /\.(woff|woff2|eot|ttf|otf)$/,
      use: [{
        loader: "url-loader",
        options: {
          limit: 10000,
          name: "static/fonts/[name].[hash:7].[ext]"
        }
      }]
    }, {
      test: /\.(mp4|webm|ogg|mp3|wav|flac|aac)(\?.*)?$/,
      use: [{
        loader: "url-loader",
        options: {
          limit: 10000,
          name: "static/media/[name].[hash:7].[ext]"
        }
      }]
    }]
  },
  plugins: [// new MiniCssExtractPlugin({
  //   filename: "[name]_[contenthash:8].css"
  // }),
  // new VueLoaderPlugin(),
  new CleanWebpackPlugin(), new HtmlWebpackPlugin({
    filename: "index.html",
    template: path.join(projectRoot, "index.html") // inject: true,

  }), new CopyWebpackPlugin([{
    from: path.join(projectRoot, "./static"),
    to: "static",
    ignore: [".*"]
  }])] //   function errorPlugin() {
  //     this.hooks.done.tap('done', (stats) => {
  //       if (stats.compilation.errors && stats.compilation.errors.length && process.argv.indexOf('--watch') === -1) {
  //         process.exit(1);
  //       }
  //     });
  //   },
  // ].concat(htmlWebpackPlugins)

};
